import moment from 'moment';
import React, { useCallback, useEffect, useMemo, useState } from 'react';
import { FlatList, Text, View } from 'react-native';
import { isEmpty, isNil } from '../utils/commonUtil';
import { BaseCardDateText, StyledDateCard, StyledRNAppointmentCalendarContainer, TimeCardContainer } from './rnAppointmentCalendarStyle';
export const RNAppointmentCalendar = (props) => {
    //Variables
    const { date = moment().toDate(), format = 'YYYY-MM-DD HH:mm', includeTimes, disabledDates, bookedTimes, selectedTimes, monthRange = 1, timeInterval = 30, withTimes = true, isMultipleTimeSelect = false, unSelectedTimeComponent, colors, dateCardPositions, styleDateFlatList, styleTimeFlatList, onDateSelect, onTimeSelect, onDateTimeSelect } = props;
    const days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    const _date = moment().toDate();
    const _dateFormat = 'YYYY-MM-DD';
    const initialMonth = _date.getMonth();
    const initialYear = _date.getFullYear();
    // States
    const [activeDate, setActiveDate] = useState(!(disabledDates === null || disabledDates === void 0 ? void 0 : disabledDates.includes(moment(date).format(_dateFormat).toString())) ? date : undefined);
    const [activeTime, setActiveTime] = useState((activeDate && (isMultipleTimeSelect ? [moment(date).format('HH:mm')] : moment(date).format('HH:mm'))) || undefined);
    // Functions
    const isSelectedDate = ({ date, day, month, year }) => {
        return moment(date).format(_dateFormat) === moment(`${year}-${month}-${day}`).format(_dateFormat);
    };
    const getValueAccordingByMultipleSelecting = ({ value, prev }) => {
        return isMultipleTimeSelect && prev && typeof prev !== 'string' ? [...prev, value] : value;
    };
    const handleDatePress = ({ item }) => {
        const itemDate = moment(`${item.year}-${item.month}-${item.day}`, _dateFormat).toDate();
        setActiveDate(itemDate);
        setActiveTime(getValueAccordingByMultipleSelecting({ value: undefined, prev: [] }));
    };
    const handleSetActiveTime = (prev, item) => {
        if (Array.isArray(prev) && prev.some((_item) => _item === item)) {
            return prev === null || prev === void 0 ? void 0 : prev.filter((_item) => _item !== item);
        }
        return getValueAccordingByMultipleSelecting({ value: item, prev });
    };
    const handleTimePress = ({ time }) => {
        if (typeof activeTime !== 'string') {
            setActiveTime((prev) => handleSetActiveTime(prev, time));
            return;
        }
        setActiveTime((prev) => getValueAccordingByMultipleSelecting({ value: time, prev }));
    };
    const isBookedTime = useMemo(() => bookedTimes && bookedTimes[moment(activeDate).format(_dateFormat)], [activeDate, bookedTimes]);
    const isSelectedTime = useMemo(() => selectedTimes && selectedTimes[moment(activeDate).format(_dateFormat)], [activeDate, selectedTimes]);
    const checkSelectedTime = ({ time }) => {
        if (isMultipleTimeSelect) {
            return (activeTime === null || activeTime === void 0 ? void 0 : activeTime.includes(time)) || (isSelectedTime === null || isSelectedTime === void 0 ? void 0 : isSelectedTime.includes(time));
        }
        return activeTime === time || (Array.isArray(isSelectedTime) && isSelectedTime[0] === time) || false;
    };
    const getSelectedDateTimes = () => {
        if (Array.isArray(activeTime)) {
            return activeTime
                .map((time) => {
                return time && moment(`${moment(activeDate).format(_dateFormat)} ${time}`).format(format);
            })
                .filter((time) => !isEmpty(time));
        }
        return moment(`${moment(activeDate).format(_dateFormat)} ${activeTime}`).format(format);
    };
    const generateCalendar = useMemo(() => {
        const dates = [];
        let year = initialYear;
        for (let m = initialMonth; m <= initialMonth + monthRange; m++) {
            const monthIndex = m - 12 >= 0 ? m - 12 : m;
            const month = m - 11 > 0 ? m - 11 : m + 1;
            const getDays = days[monthIndex];
            year = monthIndex === 0 ? year + 1 : year;
            for (let i = 1; i <= getDays; i++) {
                const parsedDay = `0${i.toString()}`.slice(-2);
                const parsedMonth = `0${month.toString()}`.slice(-2);
                const isDisabled = (disabledDates &&
                    (disabledDates === null || disabledDates === void 0 ? void 0 : disabledDates.includes(moment(`${year}-${parsedMonth}-${parsedDay}`).format(_dateFormat).toString()))) ||
                    false;
                const isCurrentDate = !isDisabled
                    ? isSelectedDate({ date: _date, day: parsedDay, month: parsedMonth, year })
                    : false;
                const isSelected = !isDisabled
                    ? isSelectedDate({ date: activeDate, day: parsedDay, month: parsedMonth, year })
                    : false;
                dates.push({
                    id: `${m}${i}`,
                    day: parsedDay,
                    month: parsedMonth,
                    year: year.toString(),
                    isCurrentDate,
                    isSelected,
                    isDisabled
                });
            }
        }
        return dates.slice(moment().toDate().getDate() - 1, dates.length);
    }, [activeDate]);
    const getTimeRanges = useCallback((interval) => {
        var _a;
        const ranges = [];
        const date = moment().toDate();
        for (let minutes = 0; minutes < 24 * 60; minutes = minutes + interval) {
            date.setHours(0);
            date.setMinutes(minutes);
            const time = moment(date).format('HH:mm').toString();
            ranges.push({
                id: minutes.toString(),
                time,
                isSelected: checkSelectedTime({ time }),
                isBooked: (isBookedTime === null || isBookedTime === void 0 ? void 0 : isBookedTime.includes(time)) || false,
                isDisabled: (includeTimes && !((_a = includeTimes[moment(activeDate).format(_dateFormat)]) === null || _a === void 0 ? void 0 : _a.includes(time))) || false
            });
        }
        return ranges;
    }, [activeDate, activeTime]);
    // Hooks
    useEffect(() => {
        activeDate && (onDateSelect === null || onDateSelect === void 0 ? void 0 : onDateSelect(moment(activeDate).format(format)));
    }, [activeDate]);
    useEffect(() => {
        activeTime && (onTimeSelect === null || onTimeSelect === void 0 ? void 0 : onTimeSelect(Array.isArray(activeTime) ? activeTime.filter((time) => !isEmpty(time)) : activeTime));
    }, [activeTime]);
    useEffect(() => {
        activeTime && (onDateTimeSelect === null || onDateTimeSelect === void 0 ? void 0 : onDateTimeSelect(getSelectedDateTimes()));
    }, [activeDate, activeTime]);
    const renderDateItem = ({ item }) => {
        const { year, month, day, isSelected, isDisabled, isCurrentDate } = item;
        return (React.createElement(StyledDateCard, { selectedBgColor: colors === null || colors === void 0 ? void 0 : colors.selectedBgColor, isSelected: isSelected, disabled: isDisabled, disableOpacity: colors === null || colors === void 0 ? void 0 : colors.disableOpacity, onPress: () => handleDatePress({ item }) }, dateCardPositions === null || dateCardPositions === void 0 ? void 0 : dateCardPositions.map((_item, _index) => _item.isVisible && (React.createElement(BaseCardDateText, { key: _index, fontSize: _item.fontSize, isSelected: isSelected, selectedColor: colors === null || colors === void 0 ? void 0 : colors.selectedColor, isCurrentDate: isCurrentDate, currentDateColor: colors === null || colors === void 0 ? void 0 : colors.currentDateColor }, _item.key === 'dayOfWeek'
            ? moment(`${year}-${month}-${day}`, _dateFormat).format('dd').toString()
            : item[_item.key])))));
    };
    const renderTimeItem = ({ item }) => {
        const { time, isSelected, isDisabled, isBooked } = item;
        return (React.createElement(TimeCardContainer, { onPress: () => handleTimePress({ time }), isSelected: isSelected, selectedBgColor: colors === null || colors === void 0 ? void 0 : colors.selectedBgColor, isBooked: isBooked, disabled: isDisabled, disableOpacity: colors === null || colors === void 0 ? void 0 : colors.disableOpacity },
            React.createElement(BaseCardDateText, { fontSize: 12, isSelected: isSelected, selectedColor: colors === null || colors === void 0 ? void 0 : colors.selectedColor }, time)));
    };
    return (React.createElement(StyledRNAppointmentCalendarContainer, null,
        React.createElement(React.Fragment, null,
            React.createElement(FlatList, { data: generateCalendar, renderItem: renderDateItem, keyExtractor: (item) => item.id, horizontal: true, style: {
                    marginBottom: 30,
                    flexGrow: 0,
                    ...styleDateFlatList
                } })),
        withTimes && (React.createElement(React.Fragment, null, !isNil(activeDate) ? (React.createElement(FlatList, { data: getTimeRanges(timeInterval), numColumns: 3, renderItem: renderTimeItem, horizontal: false, keyExtractor: (item) => item.id, style: { ...styleTimeFlatList } })) : !isEmpty(unSelectedTimeComponent) ? ({ unSelectedTimeComponent }) : (React.createElement(View, null,
            React.createElement(Text, null, "Not have any selected date.")))))));
};
RNAppointmentCalendar.defaultProps = {
    colors: {
        selectedBgColor: '#328ae8',
        selectedColor: '#FFFFFF',
        currentDateColor: '#328ae8',
        disableOpacity: 0.5
    },
    dateCardPositions: [
        {
            key: 'dayOfWeek',
            isVisible: true,
            fontSize: 12
        },
        {
            key: 'day',
            isVisible: true,
            fontSize: 20
        },
        {
            key: 'month',
            isVisible: true,
            fontSize: 14
        },
        {
            key: 'year',
            isVisible: true,
            fontSize: 10
        }
    ]
};
//# sourceMappingURL=RNAppointmentCalendar.js.map